@@ -1,19 +1,20 @@
 /*
- * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of Liblinphone.
+ * This file is part of Liblinphone 
+ * (see https://gitlab.linphone.org/BC/public/liblinphone).
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU Affero General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Affero General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Affero General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -473,6 +474,31 @@ LINPHONE_PUBLIC bool_t linphone_factory_is_download_dir_set(const LinphoneFactor
  */
 LINPHONE_PUBLIC void linphone_factory_set_download_dir(LinphoneFactory *factory, const char *path);
 
+/**
+ * Get the cache path
+ * @param factory the #LinphoneFactory @notnil
+ * @param context used to compute path. Can be NULL. JavaPlatformHelper on Android and char *appGroupId on iOS with shared core. @maybenil
+ * @return The cache path @maybenil
+ * @ingroup misc
+**/
+LINPHONE_PUBLIC const char *linphone_factory_get_cache_dir(LinphoneFactory *factory, void *context);
+
+/**
+ * Test if cache dir has been set.
+ * @param factory the #LinphoneFactory @notnil
+ * @return TRUE if cache dir has been set.
+ * @ingroup misc
+**/
+LINPHONE_PUBLIC bool_t linphone_factory_is_cache_dir_set(const LinphoneFactory *factory);
+
+/**
+ * Set the directory where the application local cache is located.
+ * If the path is empty (default value), the path will be computed when calling linphone_factory_get_data_dir()
+ * @param factory #LinphoneFactory object @notnil
+ * @param path The path to the directory where the application local cache is located @maybenil
+ */
+LINPHONE_PUBLIC void linphone_factory_set_cache_dir(LinphoneFactory *factory, const char *path);
+
 /**
  * Creates an object LinphoneErrorInfo.
  * @param factory #LinphoneFactory object @notnil
@@ -515,6 +541,14 @@ LINPHONE_PUBLIC const bctbx_list_t * linphone_factory_get_dial_plans(const Linph
  */
 LINPHONE_PUBLIC LinphoneContent *linphone_factory_create_content(LinphoneFactory *factory);
 
+/**
+ * Creates a file object of #LinphoneContent from a file path.
+ * @param factory the #LinphoneFactory @notnil
+ * @param file_path the path of the file @notnil
+ * @return a #LinphoneContent which can be used as a file @notnil
+ */
+LINPHONE_PUBLIC LinphoneContent *linphone_factory_create_content_from_file(LinphoneFactory *factory, const char * file_path);
+
 /**
  * Creates an object #LinphoneBuffer
  * @param factory the #LinphoneFactory @notnil
@@ -685,6 +719,49 @@ LINPHONE_PUBLIC LinphoneConferenceInfo *linphone_factory_create_conference_info(
  */
 LINPHONE_PUBLIC LinphoneConferenceInfo *linphone_factory_create_conference_info_from_icalendar_content(LinphoneFactory *factory, LinphoneContent *content);
 
+/**
+ * Creates an object #LinphoneConferenceSchedulerCbs
+ * @param factory the #LinphoneFactory @notnil
+ * @return a #LinphoneConferenceSchedulerCbs @notnil
+ */
+LINPHONE_PUBLIC LinphoneConferenceSchedulerCbs *linphone_factory_create_conference_scheduler_cbs(LinphoneFactory *factory);
+
+/**
+ * Indicates if the QRCode feature is available.
+ * @param factory the #LinphoneFactory @maybenil
+ * @return TRUE if QRCodes can be used
+ */
+LINPHONE_PUBLIC bool_t linphone_factory_is_qrcode_available(LinphoneFactory *factory);
+
+/**
+ * Creates a Bitmap QRCode and return it into an object #LinphoneContent
+ * @param factory the #LinphoneFactory @notnil
+ * @param code The code to be generated into an image. It must not be empty. @notnil
+ * @param width The requested width of the QRCode image. It will be 100 if 0.
+ * @param height The requested height of the QRCode image. It will be 100 if 0.
+ * @param margin The requested margin of the QRCode image.
+ * @return a #LinphoneContent @maybenil
+ */
+LINPHONE_PUBLIC LinphoneContent *linphone_factory_create_qrcode(LinphoneFactory *factory, const char * code, unsigned int width, unsigned int height, unsigned int margin);
+
+/**
+ * Creates a QRCode and write it into a JPEG file specified by file_path (only if build with JPEG).
+ * @param factory the #LinphoneFactory @notnil
+ * @param file_path The file where to write the QRCode JPEG image. @notnil
+ * @param code The code to be generated into an image. It must not be empty. @notnil
+ * @param width The requested width of the QRCode image. It will be 100 if 0.
+ * @param height The requested height of the QRCode image. It will be 100 if 0.
+ * @param margin The requested margin of the QRCode image.
+ * @return 0 if successful, -2 if JPEG is not supported, -1 otherwise
+ */
+LINPHONE_PUBLIC int linphone_factory_write_qrcode_file(LinphoneFactory *factory, const char *file_path, const char * code, unsigned int width, unsigned int height, unsigned int margin);
+
+/**
+ * Creates an object #LinphoneVideoSourceDescriptor
+ * @param factory the #LinphoneFactory @notnil
+ * @return a #LinphoneVideoSourceDescriptor @notnil
+ */
+LINPHONE_PUBLIC LinphoneVideoSourceDescriptor *linphone_factory_create_video_source_descriptor(LinphoneFactory *factory);
 
 /************ */
 /* DEPRECATED */
